@@ -30,7 +30,6 @@ __all__ = (
     "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
     "ExperimentTemplateS3LogConfigurationInputTypeDef",
     "CreateExperimentTemplateStopConditionInputTypeDef",
-    "ResponseMetadataTypeDef",
     "ExperimentTemplateTargetInputFilterTypeDef",
     "DeleteExperimentTemplateRequestRequestTypeDef",
     "ExperimentActionStateTypeDef",
@@ -53,8 +52,10 @@ __all__ = (
     "ListExperimentTemplatesRequestRequestTypeDef",
     "ListExperimentsRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "ListTargetResourceTypesRequestRequestTypeDef",
     "TargetResourceTypeSummaryTypeDef",
+    "ResponseMetadataTypeDef",
     "StartExperimentRequestRequestTypeDef",
     "StopExperimentRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -66,7 +67,6 @@ __all__ = (
     "ActionTypeDef",
     "CreateExperimentTemplateLogConfigurationInputTypeDef",
     "UpdateExperimentTemplateLogConfigurationInputTypeDef",
-    "ListTagsForResourceResponseTypeDef",
     "CreateExperimentTemplateTargetInputTypeDef",
     "UpdateExperimentTemplateTargetInputTypeDef",
     "ExperimentActionTypeDef",
@@ -188,17 +188,6 @@ class CreateExperimentTemplateStopConditionInputTypeDef(
     pass
 
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 ExperimentTemplateTargetInputFilterTypeDef = TypedDict(
     "ExperimentTemplateTargetInputFilterTypeDef",
     {
@@ -388,6 +377,14 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListTargetResourceTypesRequestRequestTypeDef = TypedDict(
     "ListTargetResourceTypesRequestRequestTypeDef",
     {
@@ -406,6 +403,17 @@ TargetResourceTypeSummaryTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredStartExperimentRequestRequestTypeDef = TypedDict(
     "_RequiredStartExperimentRequestRequestTypeDef",
     {
@@ -563,14 +571,6 @@ UpdateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
     total=False,
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "tags": Dict[str, str],
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 _RequiredCreateExperimentTemplateTargetInputTypeDef = TypedDict(
     "_RequiredCreateExperimentTemplateTargetInputTypeDef",
     {
@@ -688,7 +688,7 @@ ListExperimentTemplatesResponseTypeDef = TypedDict(
     {
         "experimentTemplates": List[ExperimentTemplateSummaryTypeDef],
         "nextToken": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -710,7 +710,7 @@ ListTargetResourceTypesResponseTypeDef = TypedDict(
     {
         "targetResourceTypes": List[TargetResourceTypeSummaryTypeDef],
         "nextToken": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -729,7 +729,7 @@ ListActionsResponseTypeDef = TypedDict(
     {
         "actions": List[ActionSummaryTypeDef],
         "nextToken": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -737,7 +737,7 @@ GetActionResponseTypeDef = TypedDict(
     "GetActionResponseTypeDef",
     {
         "action": ActionTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -801,7 +801,7 @@ ListExperimentsResponseTypeDef = TypedDict(
     {
         "experiments": List[ExperimentSummaryTypeDef],
         "nextToken": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -845,7 +845,7 @@ GetTargetResourceTypeResponseTypeDef = TypedDict(
     "GetTargetResourceTypeResponseTypeDef",
     {
         "targetResourceType": TargetResourceTypeTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -853,7 +853,7 @@ GetExperimentResponseTypeDef = TypedDict(
     "GetExperimentResponseTypeDef",
     {
         "experiment": ExperimentTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -861,7 +861,7 @@ StartExperimentResponseTypeDef = TypedDict(
     "StartExperimentResponseTypeDef",
     {
         "experiment": ExperimentTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -869,7 +869,7 @@ StopExperimentResponseTypeDef = TypedDict(
     "StopExperimentResponseTypeDef",
     {
         "experiment": ExperimentTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -877,7 +877,7 @@ CreateExperimentTemplateResponseTypeDef = TypedDict(
     "CreateExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": ExperimentTemplateTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -885,7 +885,7 @@ DeleteExperimentTemplateResponseTypeDef = TypedDict(
     "DeleteExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": ExperimentTemplateTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -893,7 +893,7 @@ GetExperimentTemplateResponseTypeDef = TypedDict(
     "GetExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": ExperimentTemplateTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -901,6 +901,6 @@ UpdateExperimentTemplateResponseTypeDef = TypedDict(
     "UpdateExperimentTemplateResponseTypeDef",
     {
         "experimentTemplate": ExperimentTemplateTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
